<?php
App::uses('EvBasketAppModel', 'EvBasket.Model');
/**
 * Basket Model
 *
 * @property BasketItem $BasketItem
 * @property BasketTotal $BasketTotal
 */
class Basket extends EvBasketAppModel {

	//The Associations below have been created with all possible keys, those that are not needed can be removed

	/**
	 * hasMany associations
	 *
	 * @var array
	 */
	public $hasMany = array(
		'BasketItem' => array(
			'className' => 'EvBasket.BasketItem'
		),
		'BasketTotal' => array(
			'className' => 'EvBasket.BasketTotal'
		)
	);

	/**
	 * convience method to get the full basket
	 *
	 * @param 	string 	$hash 			The hash identifier
	 * @param 	array 	$itemContain
	 * @return  array|null
	 */
	public function getFullBasket($hash, $itemContain) {
		return $this->find(
			'first',
			array(
				'conditions' => array(
					'Basket.hash' => $hash
				),
				'contain' => array(
					'BasketItem' => $itemContain,
					'BasketTotal' => array(
						'order' => 'BasketTotal.sequence ASC'
					)
				)
			)
		);
	}

	/**
	 * check to see if a basket exists at the given hash
	 *
	 * @param 	string 	$hash 	hash identifier to look for
	 * @return 	bool
	 */
	public function checkExists($hash) {
		return (bool)$this->find(
			'count',
			array(
				'conditions' => array(
					'Basket.hash' => $hash
				),
			'	callbacks' => false
			)
		);
	}

	/**
	 * create a basket row with the given hash
	 *
	 * @param 	string 	$hash 	hash identifier to save basket ot
	 * @return 	array
	 */
	public function createBasket($hash) {
		$this->save(
			array(
				'Basket' => array(
					'hash' => $hash
				)
			)
		);

		return $this->getFullBasket($hash);
	}
}
